#!/usr/bin/env python

####################################################################
#       Extracts base64 encoded images from an email file
#       Copyright (C) 2005 Jesus J Del Carpio
#       
#       This program is free software; you can redistribute it and/or
#       modify it under the terms of the GNU General Public License
#       as published by the Free Software Foundation; either version 2
#       of the License, or (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
####################################################################
#
#       Description:
#       This script extracts the images found in a eml(email) file
#       and creates them, I couldn't open some attachments with 
#       Thunderbird 1.0.2 so i saved the message to an .eml file 
#       and ran this on it
#       I've only tested with Thunderbird 1.0.2 eml files :P
#
#       Usage:
#       $ pixdecode.py email.eml
#
#       License:    GPL - http://www.gnu.org/copyleft/gpl.html
#
#       Author:
#       Jj <jjdelc gmail com>
#       http://www.isgeek.net/
#       Tue Dec 20 20:50:46 GMT 2005
#
####################################################################

from sys import argv, exit
from base64 import decodestring
from StringIO import StringIO

def main():

    if len(argv) != 2:
        print "Missing input file"
        exit(0)
    else:
        try:
            f = open(argv[1],'r')
            l = f.readline()
            files = []
            while not l == '':
                
                if l.startswith("Content-Type: image/"):    #found an image!! :D
                    ### check here for other possible heading format ###
                    l = f.readline()                        #read the filename line, right under it
                    filename = l[l.index('=')+2:len(l)-2]   #extract the filename, ('    name="pic.jpg"')
                    l = f.readline()                        #Content-Transfer-Encoding: base64
                    l = f.readline()                        #Content-ID: <...>
                    l = f.readline()                        #\n
                    
                    ### Start collecting uuencoded file ###
                    uue = StringIO()
                    l = f.readline()                        #First message line
                    while l.strip() != "":
                        uue.write(l)
                        l = f.readline()
                    
                    ### This is to write the file ###
                    try:
                        out = open(filename,'wb')
                        out.write(decodestring(uue.getvalue()))
                        out.close()
                        files.append(filename)
                    except IOError:
                        print "Couldn't create file " + filename
                        exit(0)
                    except: 
                        print "Error decoding file " + filename
                        out.close()
                        #Don't exit on failed decode
                    
                l = f.readline()                            #move on...
                
            f.close()
            print "Found files:\n\t" + ", ".join(files)

        except IOError:
            print "Couldn't open file '" + argv[1] + "'"
            exit(0)

if __name__ == "__main__": main()
